@@ -725,7 +725,7 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   /* Create menu window and set its style */
   priv->menu = gtk_window_new (GTK_WINDOW_POPUP);
   gtk_window_set_type_hint (GTK_WINDOW (priv->menu), GDK_WINDOW_TYPE_HINT_MENU);
-  /*gtk_window_set_is_temporary (GTK_WINDOW (priv->menu), TRUE); */
+  gtk_window_set_is_temporary (GTK_WINDOW (priv->menu), TRUE);
   gtk_widget_set_name (priv->menu, "hildon-status-bar-popup");
   gtk_window_set_resizable (GTK_WINDOW (priv->menu), FALSE);
   gtk_window_set_decorated (GTK_WINDOW (priv->menu), FALSE);
@@ -1050,7 +1050,7 @@ advanced_backlight_plugin_dsme_update_brightness (AdvancedBacklightPlugin * vsp)
   if (!priv->has_dsme)
     return;
 
-  value = (priv->brightness_level);
+  value = (priv->brightness_level * 2) + 1;
   if (value <= 2 && !priv->allow_zero)
     value = 3;
 
@@ -1147,21 +1147,30 @@ advanced_backlight_plugin_load_settings (AdvancedBacklightPlugin * vsp)
   /* Brightness jump */
   conf_value = gconf_client_get (priv->gconf_client, GCONF_KEY_BRIGHTNESS_JUMP, NULL);
   if (conf_value)
-    priv->brightness_jump = gconf_value_get_int (conf_value);
+    {
+      priv->brightness_jump = gconf_value_get_int (conf_value);
+      gconf_value_free (conf_value);
+    }
   else
     priv->brightness_jump = 10;
 
   /* Volume jump */
   conf_value = gconf_client_get (priv->gconf_client, GCONF_KEY_VOLUME_JUMP, NULL);
   if (conf_value)
-    priv->volume_jump = gconf_value_get_int (conf_value);
+    {
+      priv->volume_jump = gconf_value_get_int (conf_value);
+      gconf_value_free (conf_value);
+    }
   else
     priv->volume_jump = 20;
 
   /* Volume beep */
   conf_value = gconf_client_get (priv->gconf_client, GCONF_KEY_VOLUME_BEEP, NULL);
   if (conf_value)
-    priv->volume_beep = gconf_value_get_bool (conf_value);
+    {
+      priv->volume_beep = gconf_value_get_bool (conf_value);
+      gconf_value_free (conf_value);
+    }
   else
     priv->volume_beep = TRUE;
 }
@@ -1197,7 +1206,7 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
   GtkWidget *dialog;
   GtkWidget *confirmation_dialog;
   gint response;
-  gint response2;
+  gint response_allow_zero;
   GtkWidget *vbox;
   GtkWidget *vbox2;
   GtkWidget *allow_zero_checkbox;
@@ -1258,8 +1267,6 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
 
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
-  /*gtk_widget_set_size_request (GTK_WIDGET (dialog), 400, -1); */
-
   gtk_widget_show_all (dialog);
   response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -1279,10 +1286,11 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
           gtk_box_pack_start (GTK_BOX (vbox2), verifytext, FALSE, FALSE, 0);
           gtk_container_add (GTK_CONTAINER (GTK_DIALOG (confirmation_dialog)->vbox), vbox2);
           gtk_widget_show_all (confirmation_dialog);
-          response2 = gtk_dialog_run (GTK_DIALOG (confirmation_dialog));
+          response_allow_zero = gtk_dialog_run (GTK_DIALOG (confirmation_dialog));
 
-          if (response2 != GTK_RESPONSE_ACCEPT)
+          if (response_allow_zero != GTK_RESPONSE_ACCEPT)
             priv->allow_zero = FALSE;
+
           gtk_widget_destroy (confirmation_dialog);
         }
 
@@ -1300,9 +1308,9 @@ advanced_backlight_plugin_configure_applet (AdvancedBacklightPlugin * vsp)
 
       advanced_backlight_plugin_update_icons (vsp);
     }
+
   gtk_widget_destroy (dialog);
   advanced_backlight_plugin_save_settings (vsp);
-
 }
 
 static void
@@ -1339,6 +1347,7 @@ advanced_backlight_plugin_load_icons (AdvancedBacklightPlugin * vsp)
   gint i, j;
   gchar icon_name[30];
   gchar *file_name;
+  GError *err;
 
   for (i = 1; i <= NUM_BRIGHTNESS_ICONS; i++)
     {
@@ -1354,7 +1363,7 @@ advanced_backlight_plugin_load_icons (AdvancedBacklightPlugin * vsp)
             {
               gdk_pixbuf_unref (priv->pixbuf[i][j]);
             }
-          GError *err = NULL;
+          err = NULL;
           if (!(priv->pixbuf[i][j] = gdk_pixbuf_new_from_file (file_name, &err)))
             {
               g_critical ("Unable to read file: %s\n", err->message);
